==> multiphasepy-1.1.2.tar.gz: multiphasepy-1.1.2/tests/test_fuzzy.py <==
# This file is part of the Multiphase Python Repository by HZDR.
#
# Copyright (C) 2023 by Helmholtz-Zentrum Dresden-Rossendorf e.V. (HZDR),
# Website: https://hzdr.de
#
# Multiphase Python Repository by HZDR is free software: you can redistribute
# it and/or modify it under the terms of the GNU General Public License as
# published by the Free Software Foundation, either version 3 of the
# License, or (at your option) any later version.
#
# Multiphase Python Repository by HZDR is distributed in the hope that it will
# be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General
# Public License for more details.
#
# You should have received a copy of the GNU General Public License along
# with the Multiphase Python Repository by HZDR. If not, see
# <http://www.gnu.org/licenses/>.

"""Test module for fuzzy logic."""

from pytest import approx
from multiphasepy import fuzzy, case
from collections import OrderedDict

s_pcc = {
    "high": [0.4, 1.0, 1.0],
    "medium": [-1.0, 0.4, 1.0],
    "low": [-1.0, -1.0, 0.4],
}

s_mre = {
    "low": [0.0, 0.0, 0.3],
    "medium": [0.0, 0.3, 1.0],
    "high": [0.3, 1.0, 1.0],
}

s_goodness = {
    "perfect": [0.7, 1.0, 1.0],
    "good": [0.5, 0.7, 0.9],
    "tolerable": [0.3, 0.5, 0.7],
    "bad": [0.1, 0.3, 0.5],
    "defect": [0.0, 0.0, 0.3],
}

analyzer = fuzzy.FuzzyAnalyzer(
    {
        "pcc": fuzzy.FuzzyMetric(-1.0, 1.0, 100, "tri", s_pcc),
        "mre": fuzzy.FuzzyMetric(0, 1.0, 100, "tri", s_mre),
    },
    fuzzy.FuzzyMetric(0, 1.0, 100, "tri", s_goodness),
    method="bisector",
)


def test_analyze():
    """Test for fuzzy logic system only."""
    assert analyzer.analyze({"pcc": 0.49, "mre": 0.36}) == approx(0.5075794)


def test_evaluate():
    """Test for fuzzy logic evaluation."""
    assert fuzzy.evaluate(
        case.FoamExtCase("tests/data/case/simple"),
        "alpha.air",
        s_pcc,
        s_mre,
        s_goodness,
    ) == OrderedDict(
        [
            ("Name", "Simple Case"),
            ("simulation-mre", approx(0.0913762)),
            ("simulation-pcc", approx(0.3491056)),
            ("reference-mre", approx(0.0892284)),
            ("reference-pcc", approx(0.7008419)),
            ("simulation-goodness", approx(0.6509574)),
            ("reference-goodness", approx(0.7132604)),
        ]
    )


def test_limit():
    """Test for fuzzy logic evaluation with error metric limitation."""
    assert fuzzy.evaluate(
        case.FoamExtCase("tests/data/case/limit"),
        "k.water",
        s_pcc,
        s_mre,
        s_goodness,
    ) == {
        "Name": "Limit Case",
        "simulation-mre": approx(7.0481137),
        "simulation-pcc": approx(0.5159733),
        "simulation-goodness": approx(0.3239526),
        "reference-mre": approx(6.1339920),
        "reference-pcc": approx(0.5202981),
        "reference-goodness": approx(0.3250974),
    }


def test_calcmetrics():
    """Test for metric evaluation."""
    assert fuzzy.calcmetrics(
        case.FoamExtCase("tests/data/case/simple"),
        "alpha.air",
        ["mre", "pcc"],
    ) == {
        "simulation-mre": approx(0.0913762),
        "simulation-pcc": approx(0.3491056),
        "reference-mre": approx(0.0892284),
        "reference-pcc": approx(0.7008419),
    }


def test_calcgoodness():
    """Test for goodness evaluation."""
    v = fuzzy.calcmetrics(
        case.FoamExtCase("tests/data/case/simple"), "alpha.air", ["mre", "pcc"]
    )

    assert fuzzy.calcgoodness(
        v,
        ["mre", "pcc"],
        s_pcc,
        s_mre,
        s_goodness,
    ) == {
        "simulation-goodness": approx(0.6509574),
        "reference-goodness": approx(0.7132604),
    }

==> multiphasepy-1.4.5.tar.gz: multiphasepy-1.4.5/tests/test_fuzzy.py <==
# This file is part of the Multiphase Python Repository by HZDR.
#
# Copyright (C) 2023 by Helmholtz-Zentrum Dresden-Rossendorf e.V. (HZDR),
# Website: https://hzdr.de
#
# Multiphase Python Repository by HZDR is free software: you can redistribute
# it and/or modify it under the terms of the GNU General Public License as
# published by the Free Software Foundation, either version 3 of the
# License, or (at your option) any later version.
#
# Multiphase Python Repository by HZDR is distributed in the hope that it will
# be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General
# Public License for more details.
#
# You should have received a copy of the GNU General Public License along
# with the Multiphase Python Repository by HZDR. If not, see
# <http://www.gnu.org/licenses/>.

"""Test module for fuzzy logic."""

from collections import OrderedDict

from pytest import approx

from multiphasepy import case, fuzzy

s_pcc = {
    "high": [0.4, 1.0, 1.0],
    "medium": [-1.0, 0.4, 1.0],
    "low": [-1.0, -1.0, 0.4],
}

s_mre = {
    "low": [0.0, 0.0, 0.3],
    "medium": [0.0, 0.3, 1.0],
    "high": [0.3, 1.0, 1.0],
}

s_goodness = {
    "perfect": [0.7, 1.0, 1.0],
    "good": [0.5, 0.7, 0.9],
    "tolerable": [0.3, 0.5, 0.7],
    "bad": [0.1, 0.3, 0.5],
    "defect": [0.0, 0.0, 0.3],
}

analyzer = fuzzy.FuzzyAnalyzer(
    {
        "pcc": fuzzy.FuzzyMetric(-1.0, 1.0, 100, "tri", s_pcc),
        "mre": fuzzy.FuzzyMetric(0, 1.0, 100, "tri", s_mre),
    },
    fuzzy.FuzzyMetric(0, 1.0, 100, "tri", s_goodness),
    method="bisector",
)


def test_analyze():
    """Test for fuzzy logic system only."""
    assert analyzer.analyze({"pcc": 0.49, "mre": 0.36}) == approx(0.5075794)


def test_evaluate():
    """Test for fuzzy logic evaluation."""
    assert fuzzy.evaluate(
        case.FoamExtCase("tests/data/case/simple"),
        "alpha.air",
        s_pcc,
        s_mre,
        s_goodness,
    ) == OrderedDict(
        [
            ("Name", "Simple Case"),
            ("simulation-mre", approx(0.0913762)),
            ("simulation-pcc", approx(0.3491056)),
            ("reference-mre", approx(0.0892284)),
            ("reference-pcc", approx(0.7008419)),
            ("simulation-goodness", approx(0.6509574)),
            ("reference-goodness", approx(0.7132604)),
        ]
    )


def test_limit():
    """Test for fuzzy logic evaluation with error metric limitation."""
    assert fuzzy.evaluate(
        case.FoamExtCase("tests/data/case/limit"),
        "k.water",
        s_pcc,
        s_mre,
        s_goodness,
    ) == {
        "Name": "Limit Case",
        "simulation-mre": approx(7.0481137),
        "simulation-pcc": approx(0.5159733),
        "simulation-goodness": approx(0.3239526),
        "reference-mre": approx(6.1339920),
        "reference-pcc": approx(0.5202981),
        "reference-goodness": approx(0.3250974),
    }


def test_calcmetrics():
    """Test for metric evaluation."""
    assert fuzzy.calcmetrics(
        case.FoamExtCase("tests/data/case/simple"),
        "alpha.air",
        ["mre", "pcc"],
    ) == {
        "simulation-mre": approx(0.0913762),
        "simulation-pcc": approx(0.3491056),
        "reference-mre": approx(0.0892284),
        "reference-pcc": approx(0.7008419),
    }


def test_calcgoodness():
    """Test for goodness evaluation."""
    v = fuzzy.calcmetrics(
        case.FoamExtCase("tests/data/case/simple"), "alpha.air", ["mre", "pcc"]
    )

    assert fuzzy.calcgoodness(
        v,
        ["mre", "pcc"],
        s_pcc,
        s_mre,
        s_goodness,
    ) == {
        "simulation-goodness": approx(0.6509574),
        "reference-goodness": approx(0.7132604),
    }
